#!/usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import inquirer from 'inquirer';
import { installAppiumServer, getDriver, installDrivers, installPlugin, runAppiumDoctor, } from './serverInstall.js';
const ui = new inquirer.ui.BottomBar();
const options = [
    {
        name: 'Install Appium Server',
        fn: installAppiumServer,
        value: 'install-server',
    },
    {
        name: 'Install Appium Drivers',
        fn: installRequiredDrivers,
        value: 'install-drivers',
    },
    {
        name: 'Install Appium Plugin',
        fn: installPlugin,
        value: 'install-plugin',
    },
    {
        name: 'Run Appium Doctor',
        fn: runAppiumDoctor,
        value: 'run-doctor',
    },
    {
        name: 'Exit',
        fn: () => __awaiter(void 0, void 0, void 0, function* () {
            ui.log.write('Exiting Appium Installer...\n');
            process.exit(0);
        }),
        value: 'exit',
    },
];
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        ui.log.write(`\n👋 Hello, Appium user ✨\n\n`);
        ui.log.write(`\n‼️  BEFORE YOU START:\n\n`);
        ui.log.write(`🌐 Make sure you have node 16 and above\n\n`);
        while (true) {
            const { selectedOption } = yield inquirer.prompt([
                {
                    type: 'list',
                    name: 'selectedOption',
                    message: 'Select an option',
                    choices: options.map((option) => option.name),
                },
            ]);
            const currentOption = options.find((option) => option.name === selectedOption);
            if (!currentOption) {
                throw new Error(`Invalid menu option selected: ${selectedOption}`);
            }
            yield currentOption.fn();
            ui.log.write(`${currentOption.name} completed\n`);
        }
    });
}
function installRequiredDrivers() {
    return __awaiter(this, void 0, void 0, function* () {
        const driverChoices = yield getDriver();
        const requiredDriverToInstall = yield inquirer.prompt([
            {
                type: 'checkbox',
                message: 'Select Drivers to install',
                name: 'drivers',
                choices: driverChoices,
            },
        ]);
        yield installDrivers(requiredDriverToInstall.drivers);
        ui.log.write('\n');
    });
}
main();
//# sourceMappingURL=index.js.map