var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import inquirer from 'inquirer';
import { promisify } from 'util';
import { exec } from 'child_process';
const run = promisify(exec);
import ora from 'ora';
import { plugins } from './plugin.js';
const ui = new inquirer.ui.BottomBar();
// @ts-ignore
import shelljs from 'shelljs';
import chalk from 'chalk';
import path from 'path';
import { fileURLToPath } from 'url';
const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
export function installAppiumServer() {
    return __awaiter(this, void 0, void 0, function* () {
        newLine();
        const spinner = ora('Installing Appium Server').start();
        try {
            yield run('npm install -g appium@next');
            const { stdout } = yield run('appium -v');
            spinner.succeed(`💥 💥 💥 Successfully installed server version ${stdout}`);
        }
        catch (err) {
            spinner.fail(err);
            throw new Error(err);
        }
        finally {
            spinner.stop();
        }
        ui.log.write('\n');
    });
}
function newLine() {
    ui.log.write('\n');
}
export function getDriver() {
    return __awaiter(this, void 0, void 0, function* () {
        newLine();
        let drivers = [];
        const spinner = ora('Fetching available official drivers').start();
        try {
            const { stdout } = yield run('appium driver list --json');
            Object.keys(JSON.parse(stdout)).forEach((value) => drivers.push({ name: value }));
            spinner.succeed();
            return drivers;
        }
        catch (err) {
            spinner.fail(err);
            spinner.stop();
        }
        finally {
            spinner.stop();
        }
    });
}
export function installDrivers(value) {
    return __awaiter(this, void 0, void 0, function* () {
        yield Promise.all(value.map((driverName) => __awaiter(this, void 0, void 0, function* () {
            yield shelljs.exec(`appium driver install ${driverName}`);
        })));
    });
}
export function runAppiumDoctor() {
    return __awaiter(this, void 0, void 0, function* () {
        const { platform } = yield inquirer.prompt([
            {
                type: 'list',
                message: 'Source ',
                name: 'platform',
                choices: ['android', 'ios', 'dev'],
            }
        ]);
        const doctorPath = path.join(__dirname + '/../node_modules/.bin/appium-doctor');
        yield shelljs.exec(`${doctorPath} --${platform}`);
    });
}
export function installPlugin() {
    return __awaiter(this, void 0, void 0, function* () {
        const requiredPlugins = yield inquirer.prompt([
            {
                type: 'checkbox',
                message: 'Select Plugins to install',
                name: 'plugins',
                choices: plugins,
                validate(answer) {
                    if (answer.length < 1) {
                        return 'You must choose at least one plugin.';
                    }
                    return true;
                },
            },
        ]);
        const { source } = yield inquirer.prompt([
            {
                type: 'list',
                message: 'Source ',
                name: 'source',
                choices: ['npm', 'github', 'git', 'local'],
            }
        ]);
        let pluginPath;
        if (source != 'npm') {
            const path = yield inquirer
                .prompt([
                {
                    name: 'pluginPath',
                    message: 'Source of plugin',
                },
            ]);
            pluginPath = path.pluginPath;
        }
        const installedPlugins = yield shelljs.exec('appium plugin list --installed --json', { silent: true });
        let pluginNamesInstalled = Object.entries(JSON.parse(installedPlugins.stdout));
        let pluginInformation = [];
        pluginNamesInstalled.map(([key, val]) => {
            // @ts-ignore
            pluginInformation.push({ pluginName: key, plugin: val.pkgName, installed: val.installed });
        });
        yield Promise.all(requiredPlugins.plugins.map((pluginName) => __awaiter(this, void 0, void 0, function* () {
            newLine();
            const pluginExists = pluginInformation.find(name => name.plugin === pluginName);
            if (pluginExists != undefined) {
                ui.log.write(chalk.yellow(`ℹ️  Plugin ${pluginName} already installed`));
                newLine();
                ui.log.write(chalk.yellow(`ℹ️  Checking if any update available for plugin ${pluginName}`));
                newLine();
                yield shelljs.exec(`appium plugin update ${pluginExists.pluginName}`);
                return;
            }
            else {
                if (!pluginPath) {
                    yield shelljs.exec(`appium plugin install --source ${source} ${pluginName}`);
                }
                else {
                    yield shelljs.exec(`appium plugin install --source ${source} --package ${pluginPath} plugin`);
                }
            }
        })));
    });
}
//# sourceMappingURL=serverInstall.js.map